import { styled } from '@mui/material/styles';
import Typography from '@mui/material/Typography';
import React from 'react';
import * as MUI from '@mui/material';

/**
 * Styled wrapper component for a clickable, scrollable flex container with a fixed height.
 *
 * @param {Object} theme - The theme object containing styling variables.
 * @returns {JSX.Element} - A styled div component.
 */
const Wrapper = styled('div')(({ theme }) => ({
  display: 'flex',
  flexDirection: 'column',
  alignItems: 'flex-start',
  gap: theme.spacing(1),
  cursor: 'pointer', // Make the entire area clickable
  maxHeight: '300px', // Set a fixed height
  overflowY: 'auto', // Make the content scrollable
  border: `2px solid white`, // Solid border
  textColor: "white",
}));

/**
 * Styled Typography component with conditional styling based on selection state.
 *
 * @param {Object} theme - The theme object containing styling variables.
 * @param {boolean} selected - Flag to determine if the text is selected.
 * @returns {JSX.Element} - A styled Typography component.
 */
const SelectedText = styled(Typography)(({ theme, selected }) => ({
  width: '100%', // Make Typography span the whole width
  color:"white", 
  fontFamily: "source-code-pro, Menlo, Monaco, Consolas, 'Courier New', monospace;",
  padding: "4px 4px 4px 8px",
  fontWeight: selected ? 'bold' : '700',
  fontSize: "15px",
  backgroundColor: selected ? "#3D96B1" : 'transparent', // Darker grey background when clicked for non-selected options
  '&:hover': {
    backgroundColor: selected ? "#3D96B1" : "#82d5ee", // Grey background on hover for non-selected options
  },
}));

/**
 * Multi-select text component displaying a title and a list of selectable options.
 *
 * @param {Object} selection - The selection object containing title and options.
 * @param {boolean} multiSelect - Flag to determine if multiple options can be selected.
 * @param {Function} indexHandler - Callback function to handle the selected option index.
 * @returns {JSX.Element} - A component with a title and a list of selectable text options.
 */
function MultiSelectText({ selection, multiSelect, indexHandler }) {
  const options = selection.options;
  const title = selection.title;

  const [selectedValues, setSelectedValues] = React.useState([]);

  const handleClick = (option) => {

    if (!multiSelect) {
      setSelectedValues([option]);
      const optionIndex = options.indexOf(option);
      console.log(optionIndex)
      indexHandler(optionIndex);

    } else {
      const currentIndex = selectedValues.indexOf(option);
      const newSelectedValues = [...selectedValues];

      if (currentIndex === -1) {
        newSelectedValues.push(option);
      } else {
        newSelectedValues.splice(currentIndex, 1);
      }

      setSelectedValues(newSelectedValues);
    }
  };

  return (
    <div>
      <MUI.Typography 
          variant='h6'
          sx={{
            //transform: 'translateX(-6px)',
            width: "100%",
            marginTop: "36px",
            fontFamily: "source-code-pro, Menlo, Monaco, Consolas, 'Courier New', monospace;",
            fontSize: "36px",
            backgroundColor: "#061525",
            lineHeight: "1.1",

          }}
          fontWeight={'bold'}
          label="County">
          
          {title} 
      </MUI.Typography>
      
      <Wrapper>
        {options.map((option) => (
          <SelectedText
            key={option}
            onClick={() => handleClick(option)}
            selected={selectedValues.includes(option)}
          >
            {option}
          </SelectedText>
        ))}
      </Wrapper>
    </div>
  );
}

export default MultiSelectText;
